# METI
METI (Morphology-Enhanced Spatial Transcriptome Analysis Integrator) is an novel analytic framework that systematically analyzes cancer cells and cells of the TME by incorporating spatial gene expression, tissue histology, and prior knowledge of cancer and TME cells. METI starts with the identification of key cellular components and their states within the TME, including various immune cells and their transcriptional states, tumor stromal components such as cancer-associated fibroblasts (CAFs), and the epithelial compartment. Meanwhile, METI offers complementary information on cell morphology for various cell type from the H&E images. The combined results from gene expression and histology features provide a comprehensive understanding of the spatial cellular composition and organization within the tissue. For more information, please check out: https://github.com/Flashiness/METI

